match2seq
================

.. automodule:: biskit.match2seq
   :members:
   :exclude-members: Test

   
   
   .. rubric:: Functions Overview

   .. autosummary::
      :nosignatures:
   
      compareModels
      compareSequences
      del2mask
      expandRepeats
      expandRepeatsLeft
      expandRepeatsRight
      getEqual
      getEqualLists
      getOpCodes
      getSkipLists
   
   

   
   
   .. rubric:: Classes Overview

   .. autosummary::
      :nosignatures:
   
      
          SequenceMatcher
      
   
   

   
   
   

   .. raw:: html
               
      <hr>
      <h2>match2seq Module Details</h2>